Document

Struct Document 

pub struct Document {
    pub meta: NodeMeta,
    pub children: Vec<Block>,
}
The root of a parsed document: a sequence of top-level Blocks.

Fields

meta: NodeMeta

Node metadata (source span).

children: Vec<Block>

The document’s top-level blocks, in source order.

Implementations

Source

impl Document

pub fn to_html(&self) -> Result<String, HtmlError>

Render this document to safe-by-default HTML with default options.

pub fn to_html_with(&self, options: &HtmlOptions) -> Result<String, HtmlError>

Render this document to HTML with explicit options.

Source

impl Document

pub fn to_markdown(&self) -> Result<String, SerializeError>

Serialize this document to canonical Markdown with default options.

pub fn to_markdown_with( &self, options: &SerializeOptions, ) -> Result<String, SerializeError>

Serialize this document to canonical Markdown with explicit options.

Source

impl Document

pub fn validate(&self) -> Vec<Diagnostic>

Validate this document’s AST shape, returning a diagnostic for each invalid or unsupported node (empty when the document is well-formed).