pub struct Span {
pub start: usize,
pub end: usize,
}Expand description
A half-open byte range start..end into the original source string. These are
absolute UTF-8 byte offsets from the start of the document (not line/column);
use LineIndex to translate an offset into a line and column.
Fields
start: usizeInclusive start byte offset.
end: usizeExclusive end byte offset (one past the last byte).
Implementations